@@ -22,7 +22,8 @@ from AnyQt import sip
 from orangewidget.report.owreport import OWReport
 from orangewidget.settings import SettingsHandler
 from orangewidget.utils.signals import get_input_meta, notify_input_helper, \
-    Output, Input
+    Output, Input, LazyValue
+
 from orangewidget.widget import OWBaseWidget
 
 if hasattr(sip, "setdestroyonexit"):
@@ -240,6 +241,12 @@ class WidgetTest(GuiTest):
                 self.skipTest("minimum size not tested as .widget was not set")
             self.check_minimum_size(widget)
 
+        def test_image_export(self):
+            widget = getattr(self, "widget", None)
+            if widget is None:
+                self.skipTest("image exporting not tested as .widget was not set")
+            self.check_export_image(widget)
+
         def test_msg_base_class(self):
             widget = getattr(self, "widget", None)
             if widget is None:
@@ -250,6 +257,8 @@ class WidgetTest(GuiTest):
             cls.test_minimum_size = test_minimum_size
         if not hasattr(cls, "test_msg_base_class"):
             cls.test_msg_base_class = test_msg_base_class
+        if not hasattr(cls, "test_image_export"):
+            cls.test_image_export = test_image_export
 
     @classmethod
     def setUpClass(cls):
@@ -569,7 +578,10 @@ class WidgetTest(GuiTest):
         # widget.outputs are old-style signals; if empty, use new style
         assert output in (out.name for out in outputs), \
             "widget {} has no output {}".format(widget.name, output)
-        return widget.signalManager.get_output(widget, output, wait)
+        value = widget.signalManager.get_output(widget, output, wait)
+        if LazyValue.is_lazy(value):
+            value = value.get_value()
+        return value
 
     @contextmanager
     def modifiers(self, modifiers):
@@ -615,6 +627,8 @@ class WidgetTest(GuiTest):
         inspect("Warning")
         inspect("Information")
 
+    def check_export_image(self, widget):
+        widget.copy_to_clipboard()
 
 class TestWidgetTest(WidgetTest):
     """Meta tests for widget test helpers"""
@@ -666,6 +680,19 @@ class TestWidgetTest(WidgetTest):
         self.send_signal("6 * 7")
         self.assertEquals(self.get_output(), 42)
 
+    def test_compute_lazy_signals(self):
+        class A(OWBaseWidget):
+            name = "A"
+
+            class Outputs(OWBaseWidget.Outputs):
+                answer = Output("Answer", int, auto_summary=False)
+
+            def __init__(self):
+                self.Outputs.answer.send(LazyValue[int](lambda: 42))
+
+        self.widget = self.create_widget(A)
+        self.assertEquals(self.get_output(), 42)
+
 
 class BaseParameterMapping:
     """Base class for mapping between gui components and learner's parameters
