@@ -3,8 +3,8 @@ from typing import Optional
 
 from AnyQt.QtCore import (
     Qt, QEvent, QObject, QAbstractItemModel, QSortFilterProxyModel,
-    QModelIndex, QSize, QRect, QPoint, QMargins, QElapsedTimer,
-    QTimer
+    QModelIndex, QSize, QRect, QMargins, QElapsedTimer,
+    QTimer, QT_VERSION
 )
 from AnyQt.QtGui import QMouseEvent, QKeyEvent, QPainter, QPalette, QPen
 from AnyQt.QtWidgets import (
@@ -13,6 +13,7 @@ from AnyQt.QtWidgets import (
     QStyledItemDelegate, QApplication
 )
 
+from orangewidget.utils import dropdown_popup_geometry
 
 # we want to have combo box maximally 25 characters wide
 MAXIMUM_CONTENTS_LENGTH = 25
@@ -115,7 +116,7 @@ class _ComboBoxListDelegate(QStyledItemDelegate):
         super().paint(painter, option, index)
         if index.data(Qt.AccessibleDescriptionRole) == "separator":
             palette = option.palette  # type: QPalette
-            brush = palette.brush(QPalette.Disabled, QPalette.Foreground)
+            brush = palette.brush(QPalette.Disabled, QPalette.WindowText)
             painter.setPen(QPen(brush, 1.0))
             rect = option.rect  # type: QRect
             y = rect.center().y()
@@ -276,10 +277,8 @@ class ComboBoxSearch(QComboBox):
                       .expandedTo(window.minimumSize())
                       .boundedTo(window.maximumSize())
                       .boundedTo(screenrect.size()))
-        popuprect = QRect(popuprect_origin.bottomLeft(), popup_size)
-
         popuprect = dropdown_popup_geometry(
-            popuprect, popuprect_origin, screenrect)
+            popup_size, popuprect_origin, screenrect)
         popup.setGeometry(popuprect)
 
         current = proxy.mapFromSource(
@@ -422,10 +421,17 @@ class ComboBoxSearch(QComboBox):
             if index.isValid() and \
                     index.flags() & (Qt.ItemIsEnabled | Qt.ItemIsSelectable):
                 self.hidePopup()
-                text = self.itemText(index.row())
                 self.setCurrentIndex(index.row())
-                self.activated[int].emit(index.row())
-                self.activated[str].emit(text)
+                qcombobox_emit_activated(self, index.row())
+
+
+def qcombobox_emit_activated(cb: QComboBox, index: int):
+    cb.activated[int].emit(index)
+    text = cb.itemText(index)
+    if QT_VERSION >= 0x050f00:  # 5.15
+        cb.textActivated.emit(text)
+    if QT_VERSION < 0x060000:  # 6.0
+        cb.activated[str].emit(text)
 
 
 def qwidget_margin_within(widget, ancestor):
@@ -456,42 +462,3 @@ def qwidget_margin_within(widget, ancestor):
     return QMargins(topleft.x(), topleft.y(),
                     r2.right() - bottomright.x(),
                     r2.bottom() - bottomright.y())
-
-
-def dropdown_popup_geometry(geometry, origin, screen):
-    # type: (QRect, QRect, QRect) -> QRect
-    """
-    Move/constrain the geometry for a drop down popup.
-
-    Parameters
-    ----------
-    geometry : QRect
-        The base popup geometry if not constrained.
-    origin : QRect
-        The origin rect from which the popup extends.
-    screen : QRect
-        The available screen geometry into which the popup must fit.
-
-    Returns
-    -------
-    geometry: QRect
-        Constrained drop down list geometry to fit into  screen
-    """
-    # if the popup  geometry extends bellow the screen and there is more room
-    # above the popup origin ...
-    geometry = QRect(geometry)
-    geometry.moveTopLeft(origin.bottomLeft() + QPoint(0, 1))
-
-    if geometry.bottom() > screen.bottom() \
-            and origin.center().y() > screen.center().y():
-        # ...flip the rect about the origin so it extends upwards
-        geometry.moveBottom(origin.top() - 1)
-
-    # fixup horizontal position if it extends outside the screen
-    if geometry.left() < screen.left():
-        geometry.moveLeft(screen.left())
-    if geometry.right() > screen.right():
-        geometry.moveRight(screen.right())
-
-    # bounded by screen geometry
-    return geometry.intersected(screen)
